==> django-froala-editor-0.9.0.tar.gz: django-froala-editor-0.9.0/froala_editor/static/froala_editor/js/langs/fr.js <==
/*!
 * froala_editor v1.1.9 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * French
 */

$.Editable.LANGS['fr'] = {
  translation: {
    "Bold": "Gras",
    "Italic": "Italique",
    "Underline": "Soulign\u00e9",
    "Strikethrough": "Barr\u00e9",
    "Font Size": "Taille de la police",
    "Color": "Couleur",
    "Background Color": "Couleur d'arri\u00e8re-plan",
    "Text Color": "Couleur du texte",
    "Format Block": "Formats",
    "Normal": "Normal",
    "Paragraph": "Paragraphe",
    "Code": "Code",
    "Quote": "Citation",
    "Heading 1": "Titre 1",
    "Heading 2": "Titre 2",
    "Heading 3": "Titre 3",
    "Heading 4": "Titre 4",
    "Heading 5": "Titre 5",
    "Heading 6": "Titre 6",
    "Alignment": "Alignement",
    "Align Left": "Aligner \u00e0 gauche",
    "Align Center": "Aligner au centre",
    "Align Right": "Aligner \u00e0 droite",
    "Justify": "Justifi\u00e9",
    "Numbered List": "Num\u00e9rotation",
    "Bulleted List": "Puces",
    "Indent Less": "Diminuer le retrait",
    "Indent More": "Augmenter le retrait",
    "Select All": "Tout s\u00e9lectionner",
    "Insert Link": "Ins\u00e9rer un lien",
    "Insert Image": "Ins\u00e9rer une image",
    "Insert Video": "Ins\u00e9rer une vid\u00e9o",
    "Undo": "Annuler",
    "Redo": "R\u00e9tablir",
    "Show HTML": "Afficher HTML",
    "Float Left": "Gauche",
    "Float None": "Aucun",
    "Float Right": "Droite",
    "Replace Image": "Remplacer l'image",
    "Remove Image": "Enlever l'image",
    "Title": "Titre",
    "Insert image": "Ins\u00e9rer une image",
    "Drop image": "D\u00e9posez l'image",
    "or click": "ou cliquez",
    "Enter URL": "Entrez l'URL",
    "Please wait!": "S'il vous pla\u00eet attendez!",
    "Are you sure? Image will be deleted.": "Etes-vous s\u00fbr? Image sera supprim\u00e9e.",
    "UNLINK": "Enlever le lien",
    "Open in new tab": "Ouvrir dans un nouvel onglet",
    "Type something": "Tapez quelque chose",
    "Cancel": "Annuler",
    "OK": "Ok",
    "Manage images": "Gestion des images",
    "Delete": "Effacer",
    "Font Family": "Polices de caract\u00e8res",
    "Insert Horizontal Line": "Ins\u00e9rez une ligne horizontale",
    "Table": "Tableau",
    "Insert table": "Ins\u00e9rer un tableau",
    "Cell": "Cellule",
    "Row": "Ligne",
    "Column": "Colonne",
    "Delete table": "Supprimer le tableau",
    "Insert cell before": "Ins\u00e9rer cellule avant",
    "Insert cell after": "Ins\u00e9rer cellule apr\u00e8s",
    "Delete cell": "Effacer la cellule",
    "Merge cells": "Fusionner les cellules",
    "Horizontal split": "Diviser horizontale",
    "Vertical split": "Diviser verticale",
    "Insert row above": "Ins\u00e9rer une ligne avant",
    "Insert row below": "Ins\u00e9rer une ligne apr\u00e8s",
    "Delete row": "Effacer la ligne",
    "Insert column before": "Ins\u00e9rer une colonne avant",
    "Insert column after": "Ins\u00e9rer une colonne apr\u00e8s",
    "Delete column": "Effacer la colonne"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.3.tar.gz: django-froala-editor-1.2.3/froala_editor/static/froala_editor/js/langs/fr.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * French
 */

$.Editable.LANGS['fr'] = {
  translation: {
    "Bold": "Gras",
    "Italic": "Italique",
    "Underline": "Soulign\u00e9",
    "Strikethrough": "Barr\u00e9",
    "Font Size": "Taille de la police",
    "Color": "Couleur",
    "Background": "Arri\u00e8re-plan",
    "Text": "Texte",
    "Format Block": "Formats",
    "Normal": "Normal",
    "Paragraph": "Paragraphe",
    "Code": "Code",
    "Quote": "Citation",
    "Heading 1": "Titre 1",
    "Heading 2": "Titre 2",
    "Heading 3": "Titre 3",
    "Heading 4": "Titre 4",
    "Heading 5": "Titre 5",
    "Heading 6": "Titre 6",
    "Block Style": "Bloquer le style",
    "Alignment": "Alignement",
    "Align Left": "Aligner \u00e0 gauche",
    "Align Center": "Aligner au centre",
    "Align Right": "Aligner \u00e0 droite",
    "Justify": "Justifi\u00e9",
    "Numbered List": "Num\u00e9rotation",
    "Bulleted List": "Puces",
    "Indent Less": "Diminuer le retrait",
    "Indent More": "Augmenter le retrait",
    "Select All": "Tout s\u00e9lectionner",
    "Insert Link": "Ins\u00e9rer un lien",
    "Insert Image": "Ins\u00e9rer une image",
    "Insert Video": "Ins\u00e9rer une vid\u00e9o",
    "Undo": "Annuler",
    "Redo": "R\u00e9tablir",
    "Show HTML": "Afficher HTML",
    "Float Left": "Gauche",
    "Float None": "Aucun",
    "Float Right": "Droite",
    "Replace Image": "Remplacer l'image",
    "Remove Image": "Enlever l'image",
    "Title": "Titre",
    "Drop image": "D\u00e9posez l'image",
    "or click": "ou cliquez",
    "or": "ou",
    "Enter URL": "Entrez l'URL",
    "Please wait!": "S'il vous pla\u00eet attendez!",
    "Are you sure? Image will be deleted.": "Etes-vous s\u00fbr? Image sera supprim\u00e9e.",
    "UNLINK": "Enlever le lien",
    "Open in new tab": "Ouvrir dans un nouvel onglet",
    "Type something": "Tapez quelque chose",
    "Cancel": "Annuler",
    "OK": "Ok",
    "Manage images": "Gestion des images",
    "Delete": "Effacer",
    "Font Family": "Polices de caract\u00e8res",
    "Insert Horizontal Line": "Ins\u00e9rez une ligne horizontale",
    "Table": "Tableau",
    "Insert table": "Ins\u00e9rer un tableau",
    "Cell": "Cellule",
    "Row": "Ligne",
    "Column": "Colonne",
    "Delete table": "Supprimer le tableau",
    "Insert cell before": "Ins\u00e9rer cellule avant",
    "Insert cell after": "Ins\u00e9rer cellule apr\u00e8s",
    "Delete cell": "Effacer la cellule",
    "Merge cells": "Fusionner les cellules",
    "Horizontal split": "Diviser horizontale",
    "Vertical split": "Diviser verticale",
    "Insert row above": "Ins\u00e9rer une ligne avant",
    "Insert row below": "Ins\u00e9rer une ligne apr\u00e8s",
    "Delete row": "Effacer la ligne",
    "Insert column before": "Ins\u00e9rer une colonne avant",
    "Insert column after": "Ins\u00e9rer une colonne apr\u00e8s",
    "Delete column": "Effacer la colonne"
  },
  direction: "ltr"
};
